#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://gtkglext.sourceforge.net/ 
# source location    : http://kent.dl.sourceforge.net/project/gtkglext/gtkglext/1.2.0/gtkglext-1.2.0.tar.gz
# last revised       : 9.9.2009
# dep                : 

softname='gtkglext'
softversion='1.2.0'
packageversion='1fb'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://kent.dl.sourceforge.net/project/gtkglext/gtkglext/1.2.0/$softnamesrc-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
gtkglext: gtkglext (OpenGL extension to GTK+ 2.0 or later)
gtkglext:
gtkglext: It provides additional GDK objects which support OpenGL rendering in
gtkglext: GTK+, and GtkWidget API add-ons to make GTK+ widgets OpenGL-capable.
gtkglext: Unlike Jane Loff's GtkGLArea, GtkGLExt provides a GtkWidget API which
gtkglext: enables OpenGL drawing for standard and custom GTK+ widgets.
gtkglext: gtkglextmm, a C++ wrapper for GtkGLExt, is also available.
gtkglext:
gtkglext:
gtkglext:
gtkglext:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --enable-static=no \
      --program-prefix="" \
      --program-suffix="" \
      --mandir=/usr/man \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS ChangeLog INSTALL COPYING COPYING.LIB NEWS \
      $dest/usr/doc/$softname-$softversion

# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,e2fsprogs,expat,fontconfig,\
freetype,gcc,glib2,gtk+2,libICE,libSM,libX11,libXau,libXcomposite,\
libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,\
libXmu,libXrandr,libXrender,libXt,libXxf86vm,libdrm,libpng,libxcb,\
mesa,pango,pixman,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/l/gtkglext/build-gtkglext.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
